#!/usr/bin/env ruby
#
# split exac turtle file.
#
# usage
# ruby split_exac_ttl.rb /data/store/rdf/variant/exac/20170410 /data/store/rdf/variant/exac/20170411
#
require 'fileutils'

class ExacTurtleSplitter

  @@head = <<HEAD
@prefix dbsnp: <http://identifiers.org/dbsnp/> .
@prefix dcterms: <http://purl.org/dc/terms/> .
@prefix ensembl: <http://identifiers.org/ensembl/> .
@prefix exac_variant: <http://identifiers.org/exac.variant/> .
@prefix exo: <http://purl.jp/bio/10/exac/> .
@prefix faldo: <http://biohackathon.org/resource/faldo#> .
@prefix foaf: <http://xmlns.com/foaf/0.1/> .
@prefix hgnc: <http://identifiers.org/hgnc/> .
@prefix obo: <http://purl.obolibrary.org/obo/> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix sio: <http://semanticscience.org/resource/> .
@prefix so: <http://purl.obolibrary.org/obo/so#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .

HEAD

  @@variant_start = /^exac_variant/
  def initialize(input_dir, output_dir)
    @input_dir = input_dir
    @output_dir = output_dir

    FileUtils.makedirs(@output_dir)
    FileUtils.cp("#{@input_dir}/identifiers.ttl", "#{@output_dir}/identifiers.ttl")
    split_entries
  end

  def split_entries
    Dir::glob("#{@input_dir}/variant.*.ttl").each do |file|
      count = 0
      puts "converting... #{file}"
      header_flag = true
      File.foreach(file).slice_before(@@variant_start).each do |block|
        if !header_flag # exclude header
          #begin
            count += 1
            file_suffix = count.div(1000)
            rdf_entry = block.join
            output_file_name = File.basename(file)
            divide_file = "#{@output_dir}/#{output_file_name.split(".")[0..-2].join(".")}_#{file_suffix.to_s}.ttl"
#            $stderr.puts "#{count}: #{divide_file}"

            unless File.exist?(divide_file)
              File.open(divide_file, "w") do |output_file|
                output_file.puts @@head
              end
            end
            File.open(divide_file, "a+") do |output_file|
              output_file.puts rdf_entry
            end
        end
        header_flag = false if header_flag
      end  # File.foreach(file).slice_before(rs) 
      puts "variant count: #{count.to_s}" 
    end  # Dir::glob.each(file)
  end  # def split_entries

  def add_prefix

  end

end

input_dir = ARGV.shift
output_dir = ARGV.shift

ExacTurtleSplitter.new(input_dir, output_dir)
